SdbClient class abstract
Database client (db or transaction).
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storeNames
→ Iterable<
String> -
Object store names.
no setterinherited
Methods
-
compatMigrate1To2(
{List< String> ? stores}) → Future<void> -
Available on SdbClient, provided by the SdbClientMigrationExtension extension
Null means all stores Need to convert SdbTimestamp format if you created before v2 idb_shim -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited